pipeline

package
v0.0.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2018 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Validator

type Validator struct {
	// contains filtered or unexported fields
}

Validator validates that a pipeline is valid

func NewValidator

func NewValidator(p *config.Pipeline) *Validator

NewValidator initializes a validator object

func (*Validator) Validate

func (v *Validator) Validate() error

Validate performs some validations on the pipeline configuration to see if it passes some simple standards such as "do deploys have resources allocated"

Directories

Path Synopsis

Jump to